import {Component, OnInit} from '@angular/core';
import {EditorComponent} from "ngx-monaco-editor-v2";
import {FormsModule} from "@angular/forms";
import {InputOutputComponent} from "../input-output/input-output.component";
import {JtrService} from "../jtr.service";
import {
  DebounceTime,
  GenerateDefaultJsonObjectString,
  MonacoJsonConfig,
  ReadOnlyMonacoJsonConfig
} from "../defaults";
import {BehaviorSubject, debounceTime} from "rxjs";

@Component({
  selector: 'app-beautify',
  standalone: true,
  imports: [
    EditorComponent,
    FormsModule,
    InputOutputComponent
  ],
  templateUrl: './beautify.component.html',
  styleUrl: './beautify.component.scss'
})
export class BeautifyComponent implements OnInit {
  $input: BehaviorSubject<string> = new BehaviorSubject<string>(GenerateDefaultJsonObjectString());
  inputOptions = MonacoJsonConfig;
  output: string = GenerateDefaultJsonObjectString(2);
  outputOptions = ReadOnlyMonacoJsonConfig;

  constructor(private service: JtrService) {
  }

  ngOnInit(): void {
    this.$input
      .pipe(debounceTime(DebounceTime))
      .subscribe(input => {
        this.update(input)
      });
  }

  update(input: string): void {
    this.service
      .beautify(input)
      .subscribe({
        next: response => {
          console.log(response);
          this.output = response.body.result;
        },
        error: response => {
          console.log(response)
          if (response.status === 499) {
            this.output = response.error.detail;
            console.log(response.error.detail);
          }
        }
      });
  }

  handleInputChange($event: any): void {
    console.log($event);
    this.$input.next($event);
  }
}
